@@ -10,7 +10,7 @@ import logging
 import os
 import subprocess
 import sys
-from functools import lru_cache # pylint: disable=syntax-error
+from functools import lru_cache  # pylint: disable=syntax-error
 
 from .utils import _debug
 
@@ -59,11 +59,7 @@ class _ExifToolProc:
                 )
             return
 
-        if exiftool:
-            self._exiftool = exiftool
-        else:
-            self._exiftool = get_exiftool_path()
-
+        self._exiftool = exiftool if exiftool else get_exiftool_path()
         self._process_running = False
         self._start_proc()
 
@@ -156,8 +152,7 @@ class ExifTool:
 
         if value is None:
             value = ""
-        command = []
-        command.append(f"-{tag}={value}")
+        command = [f"-{tag}={value}"]
         if self.overwrite:
             command.append("-overwrite_original")
         self.run_commands(*command)
@@ -193,7 +188,7 @@ class ExifTool:
             no_file: (bool) do not pass the filename to exiftool (default=False)
                      by default, all commands will be run against self.file
                      use no_file=True to run a command without passing the filename """
-        if not hasattr(self, "_process") or not self._process:
+        if not (hasattr(self, "_process") and self._process):
             raise ValueError("exiftool process is not running")
 
         if not commands:
@@ -232,20 +227,25 @@ class ExifTool:
         ver = self.run_commands("-ver", no_file=True)
         return ver.decode("utf-8")
 
-    def json(self):
-        """ return JSON dictionary from exiftool as dict """
+    def as_dict(self):
+        """ return dictionary of all EXIF tags and values from exiftool 
+            returns empty dict if no tags
+        """
         json_str = self.run_commands("-json")
         if json_str:
-            return json.loads(json_str)
+            exifdict = json.loads(json_str)
+            return exifdict[0]
         else:
-            return None
+            return dict()
+
+    def json(self):
+        """ returns JSON string containing all EXIF tags and values from exiftool """
+        return self.run_commands("-json")
 
     def _read_exif(self):
         """ read exif data from file """
-        json = self.json()
-        self.data = {k: v for k, v in json[0].items()}
+        data = self.as_dict()
+        self.data = {k: v for k, v in data.items()}
 
     def __str__(self):
-        str_ = f"file: {self.file}\nexiftool: {self._exiftoolproc._exiftool}"
-        return str_
-
+        return f"file: {self.file}\nexiftool: {self._exiftoolproc._exiftool}"
