@@ -1,8 +1,11 @@
+import fnmatch
 import glob
 import logging
+import os
 import os.path
 import pathlib
 import platform
+import re
 import sqlite3
 import subprocess
 import sys
@@ -11,10 +14,11 @@ import urllib.parse
 from plistlib import load as plistload
 
 import CoreFoundation
+import CoreServices
 import objc
 from Foundation import *
 
-from osxphotos._applescript import AppleScript
+from .fileutil import FileUtil
 
 _DEBUG = False
 
@@ -114,40 +118,6 @@ def _dd_to_dms(dd):
     return int(deg_), int(min_), sec_
 
 
-def _copy_file(src, dest, norsrc=False):
-    """ Copies a file from src path to dest path 
-        src: source path as string 
-        dest: destination path as string
-        norsrc: (bool) if True, uses --norsrc flag with ditto so it will not copy
-                resource fork or extended attributes.  May be useful on volumes that
-                don't work with extended attributes (likely only certain SMB mounts)
-                default is False
-        Uses ditto to perform copy; will silently overwrite dest if it exists
-        Raises exception if copy fails or either path is None """
-
-    if src is None or dest is None:
-        raise ValueError("src and dest must not be None", src, dest)
-
-    if not os.path.isfile(src):
-        raise FileNotFoundError("src file does not appear to exist", src)
-
-    if norsrc:
-        command = ["/usr/bin/ditto", "--norsrc", src, dest]
-    else:
-        command = ["/usr/bin/ditto", src, dest]
-
-    # if error on copy, subprocess will raise CalledProcessError
-    try:
-        result = subprocess.run(command, check=True, stderr=subprocess.PIPE)
-    except subprocess.CalledProcessError as e:
-        logging.critical(
-            f"ditto returned error: {e.returncode} {e.stderr.decode(sys.getfilesystemencoding()).rstrip()}"
-        )
-        raise e
-
-    return result.returncode
-
-
 def dd_to_dms_str(lat, lon):
     """ convert latitude, longitude in degrees to degrees, minutes, seconds as string """
     """ lat: latitude in degrees  """
@@ -179,7 +149,7 @@ def dd_to_dms_str(lat, lon):
 
 def get_system_library_path():
     """ return the path to the system Photos library as string """
-    """ only works on MacOS 10.15+ """
+    """ only works on MacOS 10.15 """
     """ on earlier versions, returns None """
     _, major, _ = _get_os_version()
     if int(major) < 15:
@@ -196,16 +166,10 @@ def get_system_library_path():
         with open(plist_file, "rb") as fp:
             pl = plistload(fp)
     else:
-        logging.warning(f"could not find plist file: {str(plist_file)}")
+        logging.debug(f"could not find plist file: {str(plist_file)}")
         return None
 
-    photospath = pl["SystemLibraryPath"]
-
-    if photospath is not None:
-        return photospath
-    else:
-        logging.warning("Could not get path to Photos database")
-        return None
+    return pl.get("SystemLibraryPath")
 
 
 def get_last_library_path():
@@ -224,7 +188,7 @@ def get_last_library_path():
 
     # get the IPXDefaultLibraryURLBookmark from com.apple.Photos.plist
     # this is a serialized CFData object
-    photosurlref = pl["IPXDefaultLibraryURLBookmark"]
+    photosurlref = pl.get("IPXDefaultLibraryURLBookmark")
 
     if photosurlref is not None:
         # use CFURLCreateByResolvingBookmarkData to de-serialize bookmark data into a CFURLRef
@@ -284,22 +248,25 @@ def list_photo_libraries():
     return lib_list
 
 
-def create_path_by_date(dest, dt):
-    """ Creates a path in dest folder in form dest/YYYY/MM/DD/
-        dest: valid path as str
-        dt: datetime.timetuple() object
-        Checks to see if path exists, if it does, do nothing and return path
-        If path does not exist, creates it and returns path"""
-    if not os.path.isdir(dest):
-        raise FileNotFoundError(f"dest {dest} must be valid path")
-    yyyy, mm, dd = dt[0:3]
-    yyyy = str(yyyy).zfill(4)
-    mm = str(mm).zfill(2)
-    dd = str(dd).zfill(2)
-    new_dest = os.path.join(dest, yyyy, mm, dd)
-    if not os.path.isdir(new_dest):
-        os.makedirs(new_dest)
-    return new_dest
+def get_preferred_uti_extension(uti):
+    """ get preferred extension for a UTI type
+        uti: UTI str, e.g. 'public.jpeg'
+        returns: preferred extension as str """
+
+    # reference: https://developer.apple.com/documentation/coreservices/1442744-uttypecopypreferredtagwithclass?language=objc
+
+    return CoreServices.UTTypeCopyPreferredTagWithClass(
+        uti, CoreServices.kUTTagClassFilenameExtension
+    )
+
+
+def findfiles(pattern, path_):
+    """Returns list of filenames from path_ matched by pattern
+       shell pattern. Matching is case-insensitive."""
+    # See: https://gist.github.com/techtonik/5694830
+
+    rule = re.compile(fnmatch.translate(pattern), re.IGNORECASE)
+    return [name for name in os.listdir(path_) if rule.match(name)]
 
 
 # TODO: this doesn't always work, still looking for a way to
@@ -319,117 +286,6 @@ def create_path_by_date(dest, dt):
 #     open_scpt.run()
 
 
-def _export_photo_uuid_applescript(
-    uuid,
-    dest,
-    filestem=None,
-    original=True,
-    edited=False,
-    live_photo=False,
-    timeout=120,
-    burst=False,
-):
-    """ Export photo to dest path using applescript to control Photos
-        If photo is a live photo, exports both the photo and associated .mov file
-        uuid: UUID of photo to export
-        dest: destination path to export to
-        filestem: (string) if provided, exported filename will be named stem.ext 
-                  where ext is extension of the file exported by photos (e.g. .jpeg, .mov, etc)
-                  If not provided, file will be named with whatever name Photos uses
-                  If filestem.ext exists, it wil be overwritten
-        original: (boolean) if True, export original image; default = True
-        edited: (boolean) if True, export edited photo; default = False
-                If photo not edited and edited=True, will still export the original image
-                caller must verify image has been edited
-        *Note*: must be called with either edited or original but not both, 
-                will raise error if called with both edited and original = True
-        live_photo: (boolean) if True, export associated .mov live photo; default = False
-        timeout: timeout value in seconds; export will fail if applescript run time exceeds timeout
-        burst: (boolean) set to True if file is a burst image to avoid Photos export error
-        Returns: list of paths to exported file(s) or None if export failed
-        Note: For Live Photos, if edited=True, will export a jpeg but not the movie, even if photo
-              has not been edited. This is due to how Photos Applescript interface works.
-    """
-
-    # setup the applescript to do the export
-    export_scpt = AppleScript(
-        """ 
-		on export_by_uuid(theUUID, thePath, original, edited, theTimeOut)
-			tell application "Photos"
-				set thePath to thePath
-				set theItem to media item id theUUID
-				set theFilename to filename of theItem
-				set itemList to {theItem}
-				
-				if original then
-					with timeout of theTimeOut seconds
-						export itemList to POSIX file thePath with using originals
-					end timeout
-				end if
-				
-				if edited then
-					with timeout of theTimeOut seconds
-						export itemList to POSIX file thePath
-					end timeout
-				end if
-				
-				return theFilename
-			end tell
-
-		end export_by_uuid
-		"""
-    )
-
-    dest = pathlib.Path(dest)
-    if not dest.is_dir:
-        raise ValueError(f"dest {dest} must be a directory")
-
-    if not original ^ edited:
-        raise ValueError(f"edited or original must be True but not both")
-
-    tmpdir = tempfile.TemporaryDirectory(prefix="osxphotos_")
-
-    # export original
-    filename = None
-    try:
-        filename = export_scpt.call(
-            "export_by_uuid", uuid, tmpdir.name, original, edited, timeout
-        )
-    except Exception as e:
-        logging.warning("Error exporting uuid %s: %s" % (uuid, str(e)))
-        return None
-
-    if filename is not None:
-        # need to find actual filename as sometimes Photos renames JPG to jpeg on export
-        # may be more than one file exported (e.g. if Live Photo, Photos exports both .jpeg and .mov)
-        # TemporaryDirectory will cleanup on return
-        filename_stem = pathlib.Path(filename).stem
-        files = glob.glob(os.path.join(tmpdir.name, "*"))
-        exported_paths = []
-        for fname in files:
-            path = pathlib.Path(fname)
-            if len(files) > 1 and not live_photo and path.suffix.lower() == ".mov":
-                # it's the .mov part of live photo but not requested, so don't export
-                logging.debug(f"Skipping live photo file {path}")
-                continue
-            if len(files) > 1 and burst and path.stem != filename_stem:
-                # skip any burst photo that's not the one we asked for
-                logging.debug(f"Skipping burst photo file {path}")
-                continue
-            if filestem:
-                # rename the file based on filestem, keeping original extension
-                dest_new = dest / f"{filestem}{path.suffix}"
-            else:
-                # use the name Photos provided
-                dest_new = dest / path.name
-            logging.debug(f"exporting {path} to dest_new: {dest_new}")
-            _copy_file(str(path), str(dest_new))
-            exported_paths.append(str(dest_new))
-        return exported_paths
-    else:
-        return None
-
-
 def _open_sql_file(dbname):
     """ opens sqlite file dbname in read-only mode
         returns tuple of (connection, cursor) """
@@ -466,3 +322,30 @@ def _db_is_locked(dbname):
         locked = True
 
     return locked
+
+
+# OSXPHOTOS_XATTR_UUID = "com.osxphotos.uuid"
+
+# def get_uuid_for_file(filepath):
+#     """ returns UUID associated with an exported file
+#         filepath: path to exported photo
+#     """
+#     attr = xattr.xattr(filepath)
+#     try:
+#         uuid_bytes = attr[OSXPHOTOS_XATTR_UUID]
+#         uuid_str = uuid_bytes.decode('utf-8')
+#     except KeyError:
+#         uuid_str = None
+#     return uuid_str
+
+# def set_uuid_for_file(filepath, uuid):
+#     """ sets the UUID associated with an exported file
+#         filepath: path to exported photo
+#         uuid: uuid string for photo
+#     """
+#     if not os.path.exists(filepath):
+#         raise FileNotFoundError(f"Missing file: {filepath}")
+
+#     attr = xattr.xattr(filepath)
+#     uuid_bytes = bytes(uuid, 'utf-8')
+#     attr.set(OSXPHOTOS_XATTR_UUID, uuid_bytes)
